aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2022-06-24 16:34:30 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2022-06-24 16:34:30 +0300
commit415910fcf960ecc054a3ab0757bbae47c4e363f7 (patch)
tree8727c9780e98a49d4f68d690dbf4dbee529da758
parent7ac2aa51f3132f4076440f9d0b4fe3d7662d133d (diff)
Fix crashing on pkg repositories created by toolchain versions less than 0.15.0
-rw-r--r--libbpkg/manifest.cxx11
1 files changed, 6 insertions, 5 deletions
diff --git a/libbpkg/manifest.cxx b/libbpkg/manifest.cxx
index a5aa728..98070ea 100644
--- a/libbpkg/manifest.cxx
+++ b/libbpkg/manifest.cxx
@@ -4106,20 +4106,21 @@ namespace bpkg
flag (package_manifest_flags::require_bootstrap_build))
{
// @@ TMP To support older repositories allow absent bootstrap build
// until toolchain 0.15.0 is released.
//
// Note that for such repositories the packages may not have any
// need for the bootstrap buildfile (may not have any dependency
// clauses, etc). Thus, we can safely set the bootstrap build
// value to an empty string if it is absent, so that the caller
// can always be sure that this value is always present for
// package manifest lists.
//
// Note: don't forget to uncomment no-bootstrap test in
// tests/manifest/testscript when removing this workaround.
//
// bad_name ("no package bootstrap build specified");
m.bootstrap_build = "";
+ m.alt_naming = false;
}
}
@@ -4106,20 +4106,21 @@ namespace bpkg
{
// @@ TMP To support older repositories allow absent bootstrap build
- // until toolchain 0.15.0 is released.
+ // and alt_naming until toolchain 0.15.0 is released.
//
// Note that for such repositories the packages may not have any
@@ -4106,20 +4106,21 @@ namespace bpkg
// Note that for such repositories the packages may not have any
// need for the bootstrap buildfile (may not have any dependency
- // clauses, etc). Thus, we can safely set the bootstrap build
- // value to an empty string if it is absent, so that the caller
- // can always be sure that this value is always present for
- // package manifest lists.
+ // clauses, etc). Thus, we can safely set the bootstrap build and
+ // alt_naming values to an empty string and false, respectively,
+ // if they are absent, so that the caller can always be sure that
+ // these values are always present for package manifest lists.
//
// Note: don't forget to uncomment no-bootstrap test in